==> elgg1.0.tar.gz: elgg1.0/actions/admin/site/update_basic.php <==
<?php

	/**
	 * Elgg update site action
	 * 
	 * This is an update version of the sitesettings/install action which is used by the admin panel to modify basic settings.
	 * 
	 * @package Elgg
	 * @subpackage Core
	 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
	 * @author Curverider Ltd
	 * @copyright Curverider Ltd 2008
	 * @link http://elgg.org/
	 */

	global $CONFIG;
	
	// block non-admin users
	admin_gatekeeper();
	action_gatekeeper();
	
	if (get_input('settings') == 'go') {
		
		if (datalist_get('default_site')) {
			
			$site = get_entity(datalist_get('default_site'));
			if (!($site instanceof ElggSite)) 
				throw new InstallationException(elgg_echo('InvalidParameterException:NonElggSite'));
			
			$site->description = get_input('sitedescription');
			$site->name = get_input('sitename');
			$site->url = get_input('wwwroot');
			
			datalist_set('path',sanitise_filepath(get_input('path')));
			datalist_set('dataroot',sanitise_filepath(get_input('dataroot')));
			
			set_config('language', get_input('language'), $site->getGUID());
			
			set_config('view', get_input('view'), $site->getGUID());
			
			$debug = get_input('debug');
			if ($debug)
				set_config('debug', 1, $site->getGUID());
			else
				unset_config('debug', $site->getGUID());
				
			$usage = get_input('usage');
			if ($usage)
				unset_config('ping_home', $site->getGUID());
			else
				set_config('ping_home', 'disabled', $site->getGUID());
			
			// Now ping home
			//if ((!isset($usage)) || ($usage!='disabled'))
			//{
			//	ping_home($site);
			//}
				
			if ($site->save())
				system_message(elgg_echo("admin:configuration:success"));
			else
				register_error(elgg_echo("admin:configuration:fail"));
			
			header("Location: {$CONFIG->wwwroot}admin/site/");
			exit;
			
		}
		
	}

?>

==> elgg1.1.tar.gz: elgg1.1/actions/admin/site/update_basic.php <==
<?php

	/**
	 * Elgg update site action
	 * 
	 * This is an update version of the sitesettings/install action which is used by the admin panel to modify basic settings.
	 * 
	 * @package Elgg
	 * @subpackage Core
	 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
	 * @author Curverider Ltd
	 * @copyright Curverider Ltd 2008
	 * @link http://elgg.org/
	 */

	global $CONFIG;
	
	// block non-admin users
	admin_gatekeeper();
	action_gatekeeper();
	
	if (get_input('settings') == 'go') {
		
		if (datalist_get('default_site')) {
			
			$site = get_entity(datalist_get('default_site'));
			if (!($site instanceof ElggSite)) 
				throw new InstallationException(elgg_echo('InvalidParameterException:NonElggSite'));
			
			$site->description = get_input('sitedescription');
			$site->name = get_input('sitename');
			$site->email = get_input('siteemail');
			$site->url = get_input('wwwroot');
			
			datalist_set('path',sanitise_filepath(get_input('path')));
			datalist_set('dataroot',sanitise_filepath(get_input('dataroot')));
			
			set_config('language', get_input('language'), $site->getGUID());
			
			set_config('view', get_input('view'), $site->getGUID());
			
			$debug = get_input('debug');
			if ($debug)
				set_config('debug', 1, $site->getGUID());
			else
				unset_config('debug', $site->getGUID());
				
			$usage = get_input('usage');
			if ($usage)
				unset_config('ping_home', $site->getGUID());
			else
				set_config('ping_home', 'disabled', $site->getGUID());
				
			$api = get_input('api');
			if ($api)
				unset_config('disable_api', $site->getGUID());
			else
				set_config('disable_api', 'disabled', $site->getGUID());
			
			// Now ping home
			//if ((!isset($usage)) || ($usage!='disabled'))
			//{
			//	ping_home($site);
			//}
				
			if ($site->save())
				system_message(elgg_echo("admin:configuration:success"));
			else
				register_error(elgg_echo("admin:configuration:fail"));
			
			//header("Location: {$CONFIG->wwwroot}admin/site/");
			forward($_SERVER['HTTP_REFERER']);
			exit;
			
		}
		
	}

?>
